@@ -3,16 +3,17 @@ package shell
 import (
 	"bytes"
 	"errors"
+	"fmt"
 	"io/ioutil"
 	"os"
 	"os/exec"
 	"path/filepath"
-
-	"fmt"
+	"runtime"
 	"time"
 
 	"github.com/kardianos/osext"
 	"github.com/sirupsen/logrus"
+
 	"gitlab.com/gitlab-org/gitlab-runner/common"
 	"gitlab.com/gitlab-org/gitlab-runner/executors"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers"
@@ -134,9 +135,10 @@ func init() {
 	}
 
 	options := executors.ExecutorOptions{
-		DefaultBuildsDir: "$PWD/builds",
-		DefaultCacheDir:  "$PWD/cache",
-		SharedBuildsDir:  true,
+		DefaultCustomBuildsDirEnabled: false,
+		DefaultBuildsDir:              "$PWD/builds",
+		DefaultCacheDir:               "$PWD/cache",
+		SharedBuildsDir:               true,
 		Shell: common.ShellScriptInfo{
 			Shell:         common.GetDefaultShell(),
 			Type:          common.LoginShell,
@@ -156,6 +158,11 @@ func init() {
 	featuresUpdater := func(features *common.FeaturesInfo) {
 		features.Variables = true
 		features.Shared = true
+
+		if runtime.GOOS != "windows" {
+			features.Session = true
+			features.Terminal = true
+		}
 	}
 
 	common.RegisterExecutor("shell", executors.DefaultExecutorProvider{
